==> haskell-unliftio-core-0.1.2.0-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unliftio-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unliftio-core
version:              0.1.2.0
visibility:           public
id:                   unliftio-core-0.1.2.0-BfjjiCuGdFfJICKMeUQye4
key:                  unliftio-core-0.1.2.0-BfjjiCuGdFfJICKMeUQye4
license:              MIT
copyright:            2017 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Francesco Mazzoli
homepage:
    https://github.com/fpco/unliftio/tree/master/unliftio-core#readme

synopsis:             The MonadUnliftIO typeclass for unlifting monads to IO
description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio-core>

category:             Control
abi:                  b7b0809b79e9b2b256c64ccddd840c73
exposed:              True
exposed-modules:      Control.Monad.IO.Unlift
hidden-modules:       Paths_unliftio_core
import-dirs:          /usr/lib/ghc-8.8.1/site-local/unliftio-core-0.1.2.0
library-dirs:         /usr/lib/ghc-8.8.1/site-local/unliftio-core-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/unliftio-core-0.1.2.0
hs-libraries:         HSunliftio-core-0.1.2.0-BfjjiCuGdFfJICKMeUQye4
depends:              base-4.13.0.0 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-unliftio-core/html/unliftio-core.haddock

haddock-html:         /usr/share/doc/haskell-unliftio-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unliftio-core-0.2.0.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unliftio-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unliftio-core
version:              0.2.0.1
visibility:           public
id:                   unliftio-core-0.2.0.1-9YxW0LiOGZlEuOnmYen3Ur
key:                  unliftio-core-0.2.0.1-9YxW0LiOGZlEuOnmYen3Ur
license:              MIT
copyright:            2017-2020 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Francesco Mazzoli
homepage:
    https://github.com/fpco/unliftio/tree/master/unliftio-core#readme

synopsis:             The MonadUnliftIO typeclass for unlifting monads to IO
description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio-core>

category:             Control
abi:                  ae8a474311598e7fa2f9ce4769490569
exposed:              True
exposed-modules:      Control.Monad.IO.Unlift
hidden-modules:       Paths_unliftio_core
import-dirs:          /usr/lib/ghc-8.8.3/site-local/unliftio-core-0.2.0.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/unliftio-core-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/unliftio-core-0.2.0.1
hs-libraries:         HSunliftio-core-0.2.0.1-9YxW0LiOGZlEuOnmYen3Ur
depends:              base-4.13.0.0 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-unliftio-core/html/unliftio-core.haddock

haddock-html:         /usr/share/doc/haskell-unliftio-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
